# Metronome
Tkinter-based metronome.

To install, run 
```
pip install etronome
```
(as in 'metronome' without the 'm'). Then, to start the metronome, run 
```
python -m etronome 100
```
where 100 can be replaced with whatever bpm you'd like the metronome to run at. This requires Python 3.8 or higher. The package depends on ALSA, and as a result only runs on Linux.

The metronome click sound was taken from [Ludwig Müller](http://ludwigmueller.net) via [freesound.org](https://freesound.org).
